@@ -5,8 +5,8 @@ PointValuePair class used for maximum values in Beam
 
 class PointValuePair(object):
     """
-    Stores a point and value.  
-    Offers a show() method
+    Stores a point and value along with units.  
+    Offers a getString() method
     """
     def __init__(self, point, value, units):
         self.Point = point
@@ -17,4 +17,4 @@ class PointValuePair(object):
         """
         '[value][units] @ [point]m'
         """
-        return "{:<8} {:<6} @ {:>6} [m]".format(round(self.Value, 5), self.Units, round(self.Point, 3))
+        return "{:>9} {:<6} @ {:>6} [m]".format(f"{self.Value:.4f}", self.Units, round(self.Point, 3))
